pub struct BestModelCheckpoint { /* private fields */ }Expand description
Saves model weights when monitored metric improves.
This struct tracks the best metric value and signals when a new best is found. The caller is responsible for performing the actual model serialisation.
Implementations
Sourceimpl BestModelCheckpoint
impl BestModelCheckpoint
Sourceimpl BestModelCheckpoint
impl BestModelCheckpoint
Sourcepub fn with_monitor(self, key: impl Into<String>) -> Self
pub fn with_monitor(self, key: impl Into<String>) -> Self
Set the metric key to monitor (default: "loss").